@@ -396,6 +396,18 @@ namespace Banshee
             InterfaceElements.MainContainer = gxml["MainContainer"] as VBox;
 
             // Playlist View
+            EventBox evbox = (Gtk.EventBox)gxml["playlist_header_event_box"];
+            Widget evchild = evbox.Child;
+            evbox.Remove(evchild);
+            FadingAlignment fadalign = new FadingAlignment();
+            fadalign.BottomPadding = 4;
+            fadalign.TopPadding = 5;
+            fadalign.RightPadding = 5;
+            fadalign.LeftPadding = 6;
+            fadalign.Add(evchild);
+            fadalign.Show();
+            evbox.Add(fadalign);
+             
             playlistModel = new PlaylistModel();
             playlistView = new PlaylistView(playlistModel);
             InterfaceElements.PlaylistView = playlistView;
@@ -749,6 +761,11 @@ namespace Banshee
             if(PlayerEngineCore.CurrentState != PlayerEngineState.Idle) {
                 TogglePlaying();
             } else {
+                if(SourceManager.ActiveSource.HandlesStartPlayback) {
+                    SourceManager.ActiveSource.StartPlayback();
+                    return;
+                }
+                
                 if(!playlistView.PlaySelected()) {
                     playlistModel.Advance();
                     playlistView.UpdateView();
@@ -941,7 +958,7 @@ namespace Banshee
             
             Globals.ActionManager.SongActions.Sensitive = true;
             Globals.ActionManager["WriteCDAction"].Sensitive = !(source is AudioCdSource);
-            Globals.ActionManager["RemoveSongsAction"].Sensitive = !(source is AudioCdSource);
+            Globals.ActionManager["RemoveSongsAction"].Sensitive = !(source is AudioCdSource || source is Banshee.SmartPlaylist.SmartPlaylistSource);
             Globals.ActionManager["DeleteSongsFromDriveAction"].Sensitive = 
                 !(source is AudioCdSource || source is DapSource);
             Globals.ActionManager["DeleteSongsFromDriveAction"].Visible =
@@ -1017,16 +1034,14 @@ namespace Banshee
             alignment.Add(playlist_container);
             alignment.ShowAll();
             
-            gxml["PlaylistHeaderBox"].Show();
-            gxml["PlaylistHeaderSeparator"].Show();
+            gxml["playlist_header_event_box"].Show();
         }
         
         private void ShowSourceWidget()
         {
             Alignment alignment = gxml["LibraryAlignment"] as Alignment;
             
-            gxml["PlaylistHeaderBox"].Visible = SourceManager.ActiveSource.ShowPlaylistHeader;
-            gxml["PlaylistHeaderSeparator"].Visible = SourceManager.ActiveSource.ShowPlaylistHeader;
+            gxml["playlist_header_event_box"].Visible = SourceManager.ActiveSource.ShowPlaylistHeader;
             
             if(alignment.Child == SourceManager.ActiveSource.ViewWidget) {
                 return;
@@ -1572,7 +1587,10 @@ namespace Banshee
           
             bool sensitive = playlistView.Selection.CountSelectedRows() > 0;
 
-            if(sensitive && (SourceManager.ActiveSource is LibrarySource || SourceManager.ActiveSource is PlaylistSource)) {
+            if(sensitive && (SourceManager.ActiveSource is LibrarySource ||
+                    SourceManager.ActiveSource is PlaylistSource ||
+                    SourceManager.ActiveSource is Banshee.SmartPlaylist.SmartPlaylistSource)) {
+
                 Globals.ActionManager["AddToPlaylistAction"].Visible = true;
                 Globals.ActionManager["RatingAction"].Visible = true;
             
